@@ -2,7 +2,7 @@
  * @brief Functions to handle endian specifics
  */
 /*
- * Copyright (c) 2005-2020, Christopher C. Hulbert
+ * Copyright (c) 2005-2021, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,10 @@
 /** @brief swap the bytes @c a and @c b
  * @ingroup mat_internal
  */
-#define swap(a,b)   a^=b;b^=a;a^=b
+#define swap(a, b) \
+    a ^= b;        \
+    b ^= a;        \
+    a ^= b
 
 #ifdef HAVE_MAT_INT64_T
 /** @brief swap the bytes of a 64-bit signed integer
@@ -42,20 +45,19 @@
  * @return the swapped integer
  */
 mat_int64_t
-Mat_int64Swap( mat_int64_t *a )
+Mat_int64Swap(mat_int64_t *a)
 {
-
     union {
-        mat_int8_t    i1[8];
-        mat_int64_t   i8;
+        mat_int8_t i1[8];
+        mat_int64_t i8;
     } tmp;
 
     tmp.i8 = *a;
 
-    swap( tmp.i1[0], tmp.i1[7] );
-    swap( tmp.i1[1], tmp.i1[6] );
-    swap( tmp.i1[2], tmp.i1[5] );
-    swap( tmp.i1[3], tmp.i1[4] );
+    swap(tmp.i1[0], tmp.i1[7]);
+    swap(tmp.i1[1], tmp.i1[6]);
+    swap(tmp.i1[2], tmp.i1[5]);
+    swap(tmp.i1[3], tmp.i1[4]);
 
     *a = tmp.i8;
 
@@ -70,20 +72,19 @@ Mat_int64Swap( mat_int64_t *a )
  * @return the swapped integer
  */
 mat_uint64_t
-Mat_uint64Swap( mat_uint64_t *a )
+Mat_uint64Swap(mat_uint64_t *a)
 {
-
     union {
-        mat_uint8_t    i1[8];
-        mat_uint64_t   i8;
+        mat_uint8_t i1[8];
+        mat_uint64_t i8;
     } tmp;
 
     tmp.i8 = *a;
 
-    swap( tmp.i1[0], tmp.i1[7] );
-    swap( tmp.i1[1], tmp.i1[6] );
-    swap( tmp.i1[2], tmp.i1[5] );
-    swap( tmp.i1[3], tmp.i1[4] );
+    swap(tmp.i1[0], tmp.i1[7]);
+    swap(tmp.i1[1], tmp.i1[6]);
+    swap(tmp.i1[2], tmp.i1[5]);
+    swap(tmp.i1[3], tmp.i1[4]);
 
     *a = tmp.i8;
 
@@ -97,18 +98,17 @@ Mat_uint64Swap( mat_uint64_t *a )
  * @return the swapped integer
  */
 mat_int32_t
-Mat_int32Swap( mat_int32_t *a )
+Mat_int32Swap(mat_int32_t *a)
 {
-
     union {
-        mat_int8_t    i1[4];
-        mat_int32_t   i4;
+        mat_int8_t i1[4];
+        mat_int32_t i4;
     } tmp;
 
     tmp.i4 = *a;
 
-    swap( tmp.i1[0], tmp.i1[3] );
-    swap( tmp.i1[1], tmp.i1[2] );
+    swap(tmp.i1[0], tmp.i1[3]);
+    swap(tmp.i1[1], tmp.i1[2]);
 
     *a = tmp.i4;
 
@@ -121,18 +121,17 @@ Mat_int32Swap( mat_int32_t *a )
  * @return the swapped integer
  */
 mat_uint32_t
-Mat_uint32Swap( mat_uint32_t *a )
+Mat_uint32Swap(mat_uint32_t *a)
 {
-
     union {
-        mat_uint8_t    i1[4];
-        mat_uint32_t   i4;
+        mat_uint8_t i1[4];
+        mat_uint32_t i4;
     } tmp;
 
     tmp.i4 = *a;
 
-    swap( tmp.i1[0], tmp.i1[3] );
-    swap( tmp.i1[1], tmp.i1[2] );
+    swap(tmp.i1[0], tmp.i1[3]);
+    swap(tmp.i1[1], tmp.i1[2]);
 
     *a = tmp.i4;
 
@@ -145,17 +144,16 @@ Mat_uint32Swap( mat_uint32_t *a )
  * @return the swapped integer
  */
 mat_int16_t
-Mat_int16Swap( mat_int16_t *a )
+Mat_int16Swap(mat_int16_t *a)
 {
-
     union {
-        mat_int8_t   i1[2];
-        mat_int16_t  i2;
+        mat_int8_t i1[2];
+        mat_int16_t i2;
     } tmp;
 
     tmp.i2 = *a;
 
-    swap( tmp.i1[0], tmp.i1[1] );
+    swap(tmp.i1[0], tmp.i1[1]);
 
     *a = tmp.i2;
     return *a;
@@ -167,17 +165,16 @@ Mat_int16Swap( mat_int16_t *a )
  * @return the swapped integer
  */
 mat_uint16_t
-Mat_uint16Swap( mat_uint16_t *a )
+Mat_uint16Swap(mat_uint16_t *a)
 {
-
     union {
-        mat_uint8_t   i1[2];
-        mat_uint16_t  i2;
+        mat_uint8_t i1[2];
+        mat_uint16_t i2;
     } tmp;
 
     tmp.i2 = *a;
 
-    swap( tmp.i1[0], tmp.i1[1] );
+    swap(tmp.i1[0], tmp.i1[1]);
 
     *a = tmp.i2;
     return *a;
@@ -189,18 +186,17 @@ Mat_uint16Swap( mat_uint16_t *a )
  * @return the swapped integer
  */
 float
-Mat_floatSwap( float *a )
+Mat_floatSwap(float *a)
 {
-
     union {
-        char  i1[4];
+        char i1[4];
         float r4;
     } tmp;
 
     tmp.r4 = *a;
 
-    swap( tmp.i1[0], tmp.i1[3] );
-    swap( tmp.i1[1], tmp.i1[2] );
+    swap(tmp.i1[0], tmp.i1[3]);
+    swap(tmp.i1[1], tmp.i1[2]);
 
     *a = tmp.r4;
     return *a;
@@ -212,36 +208,36 @@ Mat_floatSwap( float *a )
  * @return the swapped integer
  */
 double
-Mat_doubleSwap( double *a )
+Mat_doubleSwap(double *a)
 {
 #ifndef SIZEOF_DOUBLE
 #define SIZEOF_DOUBLE 8
 #endif
 
     union {
-        char   a[SIZEOF_DOUBLE];
+        char a[SIZEOF_DOUBLE];
         double b;
     } tmp;
 
     tmp.b = *a;
 
 #if SIZEOF_DOUBLE == 4
-    swap( tmp.a[0], tmp.a[3] );
-    swap( tmp.a[1], tmp.a[2] );
+    swap(tmp.a[0], tmp.a[3]);
+    swap(tmp.a[1], tmp.a[2]);
 #elif SIZEOF_DOUBLE == 8
-    swap( tmp.a[0], tmp.a[7] );
-    swap( tmp.a[1], tmp.a[6] );
-    swap( tmp.a[2], tmp.a[5] );
-    swap( tmp.a[3], tmp.a[4] );
+    swap(tmp.a[0], tmp.a[7]);
+    swap(tmp.a[1], tmp.a[6]);
+    swap(tmp.a[2], tmp.a[5]);
+    swap(tmp.a[3], tmp.a[4]);
 #elif SIZEOF_DOUBLE == 16
-    swap( tmp.a[0], tmp.a[15] );
-    swap( tmp.a[1], tmp.a[14] );
-    swap( tmp.a[2], tmp.a[13] );
-    swap( tmp.a[3], tmp.a[12] );
-    swap( tmp.a[4], tmp.a[11] );
-    swap( tmp.a[5], tmp.a[10] );
-    swap( tmp.a[6], tmp.a[9] );
-    swap( tmp.a[7], tmp.a[8] );
+    swap(tmp.a[0], tmp.a[15]);
+    swap(tmp.a[1], tmp.a[14]);
+    swap(tmp.a[2], tmp.a[13]);
+    swap(tmp.a[3], tmp.a[12]);
+    swap(tmp.a[4], tmp.a[11]);
+    swap(tmp.a[5], tmp.a[10]);
+    swap(tmp.a[6], tmp.a[9]);
+    swap(tmp.a[7], tmp.a[8]);
 #endif
     *a = tmp.b;
     return *a;
