@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2020, Christopher C. Hulbert
+ * Copyright (c) 2008-2021, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,19 +28,19 @@
 #define MAT5_H
 
 #ifdef __cplusplus
-#   define EXTERN extern "C"
+#define EXTERN extern "C"
 #else
-#   define EXTERN extern
+#define EXTERN extern
 #endif
 
-EXTERN mat_t    *Mat_Create5(const char *matname,const char *hdr_str);
+EXTERN mat_t *Mat_Create5(const char *matname, const char *hdr_str);
 
-EXTERN matvar_t *Mat_VarReadNextInfo5( mat_t *mat );
-EXTERN int       Mat_VarRead5(mat_t *mat, matvar_t *matvar);
-EXTERN int       Mat_VarReadData5(mat_t *mat,matvar_t *matvar,void *data,
-                     int *start,int *stride,int *edge);
-EXTERN int       Mat_VarReadDataLinear5(mat_t *mat,matvar_t *matvar,void *data,
-                     int start,int stride,int edge);
-EXTERN int       Mat_VarWrite5(mat_t *mat,matvar_t *matvar,int compress);
+EXTERN matvar_t *Mat_VarReadNextInfo5(mat_t *mat);
+EXTERN int Mat_VarRead5(mat_t *mat, matvar_t *matvar);
+EXTERN int Mat_VarReadData5(mat_t *mat, matvar_t *matvar, void *data, int *start, int *stride,
+                            int *edge);
+EXTERN int Mat_VarReadDataLinear5(mat_t *mat, matvar_t *matvar, void *data, int start, int stride,
+                                  int edge);
+EXTERN int Mat_VarWrite5(mat_t *mat, matvar_t *matvar, int compress);
 
 #endif
