@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2020, Christopher C. Hulbert
+ * Copyright (c) 2005-2021, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,21 +28,20 @@
 #define MAT73_H
 
 #ifdef __cplusplus
-#   define EXTERN extern "C"
+#define EXTERN extern "C"
 #else
-#   define EXTERN extern
+#define EXTERN extern
 #endif
 
-EXTERN mat_t    *Mat_Create73(const char *matname,const char *hdr_str);
-EXTERN int       Mat_Close73(mat_t *mat);
-EXTERN int       Mat_VarRead73(mat_t *mat,matvar_t *matvar);
-EXTERN int       Mat_VarReadData73(mat_t *mat,matvar_t *matvar,void *data,
-                     int *start,int *stride,int *edge);
-EXTERN int       Mat_VarReadDataLinear73(mat_t *mat,matvar_t *matvar,void *data,
-                     int start,int stride,int edge);
+EXTERN mat_t *Mat_Create73(const char *matname, const char *hdr_str);
+EXTERN int Mat_Close73(mat_t *mat);
+EXTERN int Mat_VarRead73(mat_t *mat, matvar_t *matvar);
+EXTERN int Mat_VarReadData73(mat_t *mat, matvar_t *matvar, void *data, int *start, int *stride,
+                             int *edge);
+EXTERN int Mat_VarReadDataLinear73(mat_t *mat, matvar_t *matvar, void *data, int start, int stride,
+                                   int edge);
 EXTERN matvar_t *Mat_VarReadNextInfo73(mat_t *mat);
-EXTERN int       Mat_VarWrite73(mat_t *mat,matvar_t *matvar,int compress);
-EXTERN int       Mat_VarWriteAppend73(mat_t *mat,matvar_t *matvar,int compress,
-                     int dim);
+EXTERN int Mat_VarWrite73(mat_t *mat, matvar_t *matvar, int compress);
+EXTERN int Mat_VarWriteAppend73(mat_t *mat, matvar_t *matvar, int compress, int dim);
 
 #endif
